@@ -1,7 +1,8 @@
 # This should import everything relevant:
-from SeedWaterSegmenter import *
-import SWHelpers
+from __future__ import absolute_import
+from .SeedWaterSegmenter import *
+from . import SWHelpers
 from ImageContour import SubContourTools
-from _version import *
+from ._version import *
 
 __all__ = ["SeedWaterSegmenter", "SWHelpers"]
